passwordless-ssh.core


connection-optionsclj

(connection-options machine)

Builds normalized SSH connection options for a machine map.

Supported auth types are:

  • "password" with :auth-secret as the password
  • "private-key" with :auth-secret as a readable private key path
Builds normalized SSH connection options for a machine map.

Supported auth types are:
- "password" with :auth-secret as the password
- "private-key" with :auth-secret as a readable private key path
sourceraw docstring

exec-machineclj

(exec-machine machine cmd)

Executes a shell command locally for localhost targets, otherwise over SSH.

Executes a shell command locally for localhost targets, otherwise over SSH.
sourceraw docstring

exec-remote-commandclj

(exec-remote-command machine cmd)

Executes a shell command on a remote machine over SSH.

Executes a shell command on a remote machine over SSH.
sourceraw docstring

localhost-machine?clj

(localhost-machine? machine)

Returns true when the machine should be treated as the local host.

Returns true when the machine should be treated as the local host.
sourceraw docstring

setup-passwordless-group-via-ssh!clj

(setup-passwordless-group-via-ssh! machines)

Bootstraps passwordless SSH for one already-compatible group of machines.

Bootstraps passwordless SSH for one already-compatible group of machines.
sourceraw docstring

setup-passwordless-mesh!clj

(setup-passwordless-mesh! machines)

Groups machines by compatible SSH authentication details and bootstraps passwordless SSH within each eligible group.

Groups machines by compatible SSH authentication details and bootstraps
passwordless SSH within each eligible group.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries