(connection-options machine)Builds normalized SSH connection options for a machine map.
Supported auth types are:
Builds normalized SSH connection options for a machine map. Supported auth types are: - "password" with :auth-secret as the password - "private-key" with :auth-secret as a readable private key path
(exec-machine machine cmd)Executes a shell command locally for localhost targets, otherwise over SSH.
Executes a shell command locally for localhost targets, otherwise over SSH.
(exec-remote-command machine cmd)Executes a shell command on a remote machine over SSH.
Executes a shell command on a remote machine over SSH.
(localhost-machine? machine)Returns true when the machine should be treated as the local host.
Returns true when the machine should be treated as the local host.
(setup-passwordless-group-via-ssh! machines)Bootstraps passwordless SSH for one already-compatible group of machines.
Bootstraps passwordless SSH for one already-compatible group of machines.
(setup-passwordless-mesh! machines)Groups machines by compatible SSH authentication details and bootstraps passwordless SSH within each eligible group.
Groups machines by compatible SSH authentication details and bootstraps passwordless SSH within each eligible group.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |